@@ -32,7 +32,7 @@ RcppExport SEXP RtoAnovaCpp(SEXP params, SEXP Ysexp, SEXP Xsexp,
 // for debug
 //    Rprintf("Input param arguments:\n tol=%g, nboot=%d, cor_type=%d, shrink_param=%g, test_type=%d, resamp=%d, reprand=%d\n",mm.tol, mm.nboot, mm.corr, mm.shrink_param, mm.test, mm.resamp, mm.reprand);
 
-    IntegerMatrix Yr(Ysexp);
+    NumericMatrix Yr(Ysexp);
     NumericMatrix Xr(Xsexp);
     IntegerMatrix INr(INsexp);
     unsigned int nRows = Yr.nrow();
