@@ -36,7 +36,7 @@ RcppExport SEXP RtoGlmSmry(SEXP mpar, SEXP tpar, SEXP Ysexp, SEXP Xsexp,
 //    // for debug
 //    Rprintf("Input param arguments:\n tol=%.4f, nboot=%d, cor_type=%d, test_type=%d, resamp=%d, reprand=%d\n",tm.tol, tm.nboot, tm.corr, tm.test, tm.resamp, tm.reprand);
 
-    IntegerMatrix Yr(Ysexp);
+    NumericMatrix Yr(Ysexp);
     NumericMatrix Xr(Xsexp);
     NumericVector lambda(LamSexp);
     unsigned int nRows = Yr.nrow();
@@ -109,8 +109,10 @@ RcppExport SEXP RtoGlmSmry(SEXP mpar, SEXP tpar, SEXP Ysexp, SEXP Xsexp,
 
     clk_end = clock();
     double dif = (double)(clk_end - clk_start)/(double)(CLOCKS_PER_SEC);
-    unsigned int min = (unsigned int) floor(dif/60);
-    Rprintf("Time elapsed: %d minutes %d seconds\n", min, (unsigned int)(dif-min*60));
+    unsigned int hours = floor(dif/3600);
+    unsigned int min = floor((dif-hours*3600)/60);
+    unsigned int sec = dif - hours*3600 - min*60;
+    Rprintf("Time elapsed: %d:%d:%d\n", hours, min, sec);
 
     // Wrap gsl vectors with Rcpp 
     double multstat, Pmultstat;
